@@ -1,3 +1,14 @@
+# -*- coding: utf-8 -*-
+'''
+    tests
+    ~~~~~
+
+    Test suite for vdirsyncer.
+
+    :copyright: (c) 2014 Markus Unterwaditzer
+    :license: MIT, see LICENSE for more details.
+'''
+
 import vdirsyncer.log
 vdirsyncer.log.set_level(vdirsyncer.log.logging.DEBUG)
 
