@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 '''
-    vdirsyncer.tests.storage.dav
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    tests.storage.dav
+    ~~~~~~~~~~~~~~~~~
 
     :copyright: (c) 2014 Markus Unterwaditzer
     :license: MIT, see LICENSE for more details.
