@@ -1,8 +1,8 @@
 
 # -*- coding: utf-8 -*-
 '''
-    vdirsyncer.tests.storage.test_memory
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+    tests.storage.test_memory
+    ~~~~~~~~~~~~~~~~~~~~~~~~~
 
     :copyright: (c) 2014 Markus Unterwaditzer
     :license: MIT, see LICENSE for more details.
