@@ -15,6 +15,10 @@ import vdirsyncer.log as log
 logger = log.get('storage.filesystem')
 
 
+def _get_etag(fpath):
+    return '{:.9f}'.format(os.path.getmtime(fpath))
+
+
 class FilesystemStorage(Storage):
 
     '''Saves data in vdir collection
@@ -24,7 +28,7 @@ class FilesystemStorage(Storage):
     _repr_attributes = ('path',)
 
     def __init__(self, path, fileext, collection=None, encoding='utf-8',
-                 **kwargs):
+                 create=True, **kwargs):
         '''
         :param path: Absolute path to a vdir or collection, depending on the
             collection parameter (see
@@ -34,10 +38,21 @@ class FilesystemStorage(Storage):
             will trigger a re-download of everything (but *should* not cause
             data-loss of any kind).
         :param encoding: File encoding for items.
+        :param create: Create directories if they don't exist.
         '''
         super(FilesystemStorage, self).__init__(**kwargs)
         if collection is not None:
             path = os.path.join(path, collection)
+        if not os.path.isdir(path):
+            if os.path.exists(path):
+                raise IOError('{} is not a directory.')
+            if create:
+                os.makedirs(path, 0750)
+            else:
+                raise IOError('Directory {} does not exist. Use create = '
+                              'True in your configuration to automatically '
+                              'create it, or create it '
+                              'yourself.'.format(path))
         self.collection = collection
         self.path = expand_path(path)
         self.encoding = encoding
@@ -61,46 +76,46 @@ class FilesystemStorage(Storage):
         for fname in os.listdir(self.path):
             fpath = os.path.join(self.path, fname)
             if os.path.isfile(fpath) and fname.endswith(self.fileext):
-                yield fname, os.path.getmtime(fpath)
+                yield fname, _get_etag(fpath)
 
     def get(self, href):
         fpath = self._get_filepath(href)
         with open(fpath, 'rb') as f:
             return (Item(f.read().decode(self.encoding)),
-                    os.path.getmtime(fpath))
+                    _get_etag(fpath))
 
     def has(self, href):
         return os.path.isfile(self._get_filepath(href))
 
-    def upload(self, obj):
-        href = self._get_href(obj.uid)
+    def upload(self, item):
+        href = self._get_href(item.uid)
         fpath = self._get_filepath(href)
         if os.path.exists(fpath):
-            raise exceptions.AlreadyExistingError(obj.uid)
+            raise exceptions.AlreadyExistingError(item.uid)
         with open(fpath, 'wb+') as f:
-            f.write(obj.raw.encode(self.encoding))
-        return href, os.path.getmtime(fpath)
+            f.write(item.raw.encode(self.encoding))
+        return href, _get_etag(fpath)
 
-    def update(self, href, obj, etag):
+    def update(self, href, item, etag):
         fpath = self._get_filepath(href)
-        if href != self._get_href(obj.uid):
+        if href != self._get_href(item.uid):
             logger.warning('href != uid + fileext: href={}; uid={}'
-                           .format(href, obj.uid))
+                           .format(href, item.uid))
         if not os.path.exists(fpath):
-            raise exceptions.NotFoundError(obj.uid)
-        actual_etag = os.path.getmtime(fpath)
+            raise exceptions.NotFoundError(item.uid)
+        actual_etag = _get_etag(fpath)
         if etag != actual_etag:
             raise exceptions.WrongEtagError(etag, actual_etag)
 
         with open(fpath, 'wb') as f:
-            f.write(obj.raw.encode('utf-8'))
-        return os.path.getmtime(fpath)
+            f.write(item.raw.encode('utf-8'))
+        return _get_etag(fpath)
 
     def delete(self, href, etag):
         fpath = self._get_filepath(href)
         if not os.path.isfile(fpath):
             raise exceptions.NotFoundError(href)
-        actual_etag = os.path.getmtime(fpath)
+        actual_etag = _get_etag(fpath)
         if etag != actual_etag:
             raise exceptions.WrongEtagError(etag, actual_etag)
         os.remove(fpath)
